CCL: SplPar Struct Reference

CCL

Data Fields
SplPar Struct Reference

`#include <ccl_cls.h>`

## Data Fields
gsl_interp_accel * | intacc
gsl_spline * | spline
double | x0
double | xf
double | y0
double | yf

## Detailed Description

Spline wrapper, used to evaluate a function outside of the supported range past the interpolation limit.

## Field Documentation

## ◆ intacc

gsl_interp_accel* SplPar::intacc

## ◆ spline

gsl_spline* SplPar::spline

## ◆ x0

double SplPar::x0

## ◆ xf

double SplPar::xf

## ◆ y0

double SplPar::y0

## ◆ yf

double SplPar::yf

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_cls.h